@@ -483,9 +483,9 @@ def payload_description(
         args = augmentations["with_module_decorations"]
         decmap = args["decorations"]
         testing_details.append(
-            "Adjustments {were} made to the following functions:\n"
+            f"Adjustments {were} made to the following functions:\n"
           + html_tools.build_list(
-                "<pre>{fn}</pre>"
+                f"<pre>{fn}</pre>"
                 for fn in decmap
             )
         )
