@@ -57,6 +57,11 @@ EVALUATION_REPORT_TEMPLATE = "standalone_report.j2"
 The template name for evaluation reports.
 """
 
+TESTS_EVALUATION_REPORT_TEMPLATE = "standalone_tests_report.j2"
+"""
+The template name for tests evaluation reports.
+"""
+
 STANDALONE_INSTRUCTIONS_TEMPLATE = "standalone_instructions.j2"
 """
 The template name for standalone instructions.
@@ -259,6 +264,33 @@ def render_report(
         )
 
 
+def render_tests_report(
+    report,
+    output_file,
+    html_output_file
+):
+    """
+    Renders a tests validation report object as JSON into the specified
+    output file, and as HTML into the specified html output file. The
+    report should come from `potluck.rubrics.Rubric.validate_tests`.
+    """
+    # Load our report template
+    template = load_template(TESTS_EVALUATION_REPORT_TEMPLATE)
+
+    # Add a timestamp to our report object
+    report["timestamp"] = time_utils.timestring()
+
+    # Render the basic report to the JSON output file
+    with open(output_file, 'w', encoding="utf-8") as fout:
+        json.dump(report, fout)
+
+    # TODO: Do we need to render any parts of the report as HTML?
+
+    # Render the HTML report to the html output file
+    with open(html_output_file, 'w', encoding="utf-8") as fout:
+        fout.write(template.render(report=report))
+
+
 #------------------------#
 # Rendering instructions #
 #------------------------#
