@@ -23,15 +23,11 @@ def whatever(a, b):
         return "Neither"
 
 
-# Expectations
+# Expectations (not tested)
 
 import optimism as opt
 
-opt.testCase(whatever(True, True))
-opt.expectResult("Both")
-opt.testCase(whatever(True, False))
-opt.expectResult("One")
-opt.testCase(whatever(False, True))
-opt.expectResult("One")
-opt.testCase(whatever(False, False))
-opt.expectResult("Neither")
+opt.expect(whatever(True, True), "Both")
+opt.expect(whatever(True, False), "One")
+opt.expect(whatever(False, True), "One")
+opt.expect(whatever(False, False), "Neither")
